@@ -74,6 +74,11 @@ the following new ones.
 
 Fetch one row and return it as an array reference.
 
+  # Process one row at a time
+  while (my $next = $results->array) {
+    say $next->[3];
+  }
+
 =head2 arrays
 
   my $collection = $results->arrays;
@@ -81,6 +86,9 @@ Fetch one row and return it as an array reference.
 Fetch all rows and return them as a L<Mojo::Collection> object containing
 array references.
 
+  # Process all rows at once
+  say $results->arrays->reduce(sub { $a->[3] + $b->[3] });
+
 =head2 columns
 
   my $columns = $results->columns;
@@ -93,6 +101,11 @@ Return column names as an array reference.
 
 Fetch one row and return it as a hash reference.
 
+  # Process one row at a time
+  while (my $next = $results->hash) {
+    say $next->{money};
+  }
+
 =head2 hashes
 
   my $collection = $results->hashes;
@@ -100,6 +113,9 @@ Fetch one row and return it as a hash reference.
 Fetch all rows and return them as a L<Mojo::Collection> object containing hash
 references.
 
+  # Process all rows at once
+  say $results->hashes->reduce(sub { $a->{money} + $b->{money} });
+
 =head2 rows
 
   my $num = $results->rows;
